==> haskell-http2-3.0.2-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http2
version:              3.0.2
visibility:           public
id:                   http2-3.0.2-GU6TQOHO2DW79dm4li4ogd
key:                  http2-3.0.2-GU6TQOHO2DW79dm4li4ogd
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http2
synopsis:             HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK, client and server.

category:             Network
abi:                  e7b39a09bc2c2e2a30289f5c6bc6f9c1
exposed:              True
exposed-modules:
    Network.HPACK Network.HPACK.Internal Network.HPACK.Table
    Network.HPACK.Token Network.HTTP2 Network.HTTP2.Client
    Network.HTTP2.Client.Internal Network.HTTP2.Frame
    Network.HTTP2.Internal Network.HTTP2.Priority
    Network.HTTP2.Priority.Internal Network.HTTP2.Server
    Network.HTTP2.Server.Internal

hidden-modules:
    Imports Network.HPACK.Builder Network.HTTP2.Client.Types
    Network.HTTP2.Client.Run Network.HPACK.HeaderBlock
    Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
    Network.HPACK.HeaderBlock.Integer Network.HPACK.Huffman
    Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
    Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
    Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
    Network.HPACK.Huffman.Tree Network.HPACK.Table.Dynamic
    Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
    Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Arch
    Network.HTTP2.Arch.Cache Network.HTTP2.Arch.Config
    Network.HTTP2.Arch.Context Network.HTTP2.Arch.EncodeFrame
    Network.HTTP2.Arch.File Network.HTTP2.Arch.HPACK
    Network.HTTP2.Arch.Manager Network.HTTP2.Arch.Queue
    Network.HTTP2.Arch.Rate Network.HTTP2.Arch.ReadN
    Network.HTTP2.Arch.Receiver Network.HTTP2.Arch.Sender
    Network.HTTP2.Arch.Status Network.HTTP2.Arch.Stream
    Network.HTTP2.Arch.Types Network.HTTP2.Frame.Decode
    Network.HTTP2.Frame.Encode Network.HTTP2.Frame.Types
    Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
    Network.HTTP2.Server.Run Network.HTTP2.Server.Types
    Network.HTTP2.Server.Worker

import-dirs:          /usr/lib/ghc-9.0.1/site-local/http2-3.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http2-3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http2-3.0.2
hs-libraries:         HShttp2-3.0.2-GU6TQOHO2DW79dm4li4ogd
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-HUle69skLlV6z807pes5m0 containers-0.6.4.1
    http-types-0.12.3-FMJeXfXZe1F6BnXFIVUYKU
    network-3.1.2.2-CXlDaZn7SUD6Bf6tae6Y5g
    network-byte-order-0.1.6-1n2ACvxYP8U7d9DVchS2z5
    psqueues-0.2.7.2-2Y62jl5WlsMI8vvUZfSP3v stm-2.5.0.0
    time-manager-0.0.0-4rcVrGBzNDpFrAIMF4m0XS
    unix-time-0.4.7-Ak5IGsTTHAvDRaJ6FXKtU5

haddock-interfaces:   /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html:         /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-3.0.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http2
version:              3.0.2
visibility:           public
id:                   http2-3.0.2-LZKiS78hBEO3em0VouAQYX
key:                  http2-3.0.2-LZKiS78hBEO3em0VouAQYX
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http2
synopsis:             HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK, client and server.

category:             Network
abi:                  0752d90c88868362039fef10aed374ed
exposed:              True
exposed-modules:
    Network.HPACK Network.HPACK.Internal Network.HPACK.Table
    Network.HPACK.Token Network.HTTP2 Network.HTTP2.Client
    Network.HTTP2.Client.Internal Network.HTTP2.Frame
    Network.HTTP2.Internal Network.HTTP2.Priority
    Network.HTTP2.Priority.Internal Network.HTTP2.Server
    Network.HTTP2.Server.Internal

hidden-modules:
    Imports Network.HPACK.Builder Network.HTTP2.Client.Types
    Network.HTTP2.Client.Run Network.HPACK.HeaderBlock
    Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
    Network.HPACK.HeaderBlock.Integer Network.HPACK.Huffman
    Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
    Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
    Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
    Network.HPACK.Huffman.Tree Network.HPACK.Table.Dynamic
    Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
    Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Arch
    Network.HTTP2.Arch.Cache Network.HTTP2.Arch.Config
    Network.HTTP2.Arch.Context Network.HTTP2.Arch.EncodeFrame
    Network.HTTP2.Arch.File Network.HTTP2.Arch.HPACK
    Network.HTTP2.Arch.Manager Network.HTTP2.Arch.Queue
    Network.HTTP2.Arch.Rate Network.HTTP2.Arch.ReadN
    Network.HTTP2.Arch.Receiver Network.HTTP2.Arch.Sender
    Network.HTTP2.Arch.Status Network.HTTP2.Arch.Stream
    Network.HTTP2.Arch.Types Network.HTTP2.Frame.Decode
    Network.HTTP2.Frame.Encode Network.HTTP2.Frame.Types
    Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
    Network.HTTP2.Server.Run Network.HTTP2.Server.Types
    Network.HTTP2.Server.Worker

import-dirs:          /usr/lib/ghc-9.0.1/site-local/http2-3.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http2-3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http2-3.0.2
hs-libraries:         HShttp2-3.0.2-LZKiS78hBEO3em0VouAQYX
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1
    case-insensitive-1.2.1.0-J1gQtd73c5YHY9YtfdlefR containers-0.6.4.1
    http-types-0.12.3-5xSWCbzPZMJ3FKkHNvWW2m
    network-3.1.2.2-9BU8QqWnKeP98A8KvbSili
    network-byte-order-0.1.6-3hnSts0cfKD6VisyGVI9jZ
    psqueues-0.2.7.2-HoHhfGOOkTIHcB4xFgTl6K stm-2.5.0.0
    time-manager-0.0.0-216Q3XHglYjB15HkYeetwg
    unix-time-0.4.7-4UZYmDn0Ka2CUZo4kH2cck

haddock-interfaces:   /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html:         /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
